pub enum SafetySelection {
Unsafe(Sequencing),
Safe(SafetySpec),
}Expand description
The choice of safety route to include in compiled routes.
SafetySelection::Unsafe: don’t use a safety route, only specify the sequencing preferenceSafetySelection::Safe: use a safety route and parameters specified by a SafetySpec.
Variants
Unsafe(Sequencing)
Don’t use a safety route, only specify the sequencing preference.
Safe(SafetySpec)
Use a safety route and parameters specified by a SafetySpec.
Implementations
Sourceimpl SafetySelection
impl SafetySelection
Sourcepub fn get_sequencing(&self) -> Sequencing
pub fn get_sequencing(&self) -> Sequencing
The sequencing preference for this selection.
Sourcepub fn get_hop_count(&self) -> usize
pub fn get_hop_count(&self) -> usize
The safety route hop count, or zero when unsafe.