Sequencing

Enum Sequencing 

pub enum Sequencing {
    PreferUnordered = 0,
    PreferOrdered = 1,
    EnsureOrdered = 2,
}
Preferred ordering of RPC message delivery over a route or for RPC messages sent to a target

  • Sequencing::PreferUnordered: any SequenceOrdering is acceptable, but SequenceOrdering::Unordered will be chosen if available
  • Sequencing::PreferOrdered: any SequenceOrdering is acceptable, but SequenceOrdering::Ordered will be chosen if available
  • Sequencing::EnsureOrdered: only SequenceOrdering::Ordered is acceptable, and if not available, the route will not be created or the message will not be sent

No sequencing preference guarantees delivery under all conditions, as there is no queuing/buffering in the network

Variants



PreferUnordered = 0

Any SequenceOrdering is acceptable, but SequenceOrdering::Unordered will be chosen if available



PreferOrdered = 1

Any SequenceOrdering is acceptable, but SequenceOrdering::Ordered will be chosen if available



EnsureOrdered = 2

Only SequenceOrdering::Ordered is acceptable, and if not available, the route will not be created or the message will not be sent

Implementations

Source

impl Sequencing

pub fn matches_ordering(&self, ordering: SequenceOrdering) -> bool

Returns true if the given ordering satisfies this sequencing requirement.