pub enum Stability {
LowLatency = 0,
Reliable = 1,
}Expand description
Choice of nodes to include in allocated routes
Stability::LowLatency: prefer nodes with low latency, but may be unreliable and require route reallocationStability::Reliable: prefer nodes with reliable uptime, but may have higher latency
Variants
LowLatency = 0
Prefer nodes with low latency, but may be unreliable and require route reallocation
Reliable = 1
Prefer nodes with reliable uptime, but may have higher latency