pub struct AtomicOptionTimestamp(/* private fields */);Expand description
Atomic wrapper for optional timestamps used in structs so we can avoid locks for LRU and similar operations
Implementations
Sourceimpl AtomicOptionTimestamp
impl AtomicOptionTimestamp
pub fn new(opt_ts: Option<Timestamp>) -> Self
pub fn none() -> Self
pub fn now() -> Self
pub fn now_non_decreasing() -> Self
pub fn now_increasing() -> Self
pub fn get(&self) -> Option<Timestamp>
pub fn set(&self, opt_t: Option<Timestamp>)
Sourcepub fn fetch_update(
&self,
f: impl FnMut(Option<Timestamp>) -> Option<Option<Timestamp>>,
) -> Result<Option<Timestamp>, Option<Timestamp>>
pub fn fetch_update( &self, f: impl FnMut(Option<Timestamp>) -> Option<Option<Timestamp>>, ) -> Result<Option<Timestamp>, Option<Timestamp>>
Fetch and update the optional timestamp atomically
Parameters:
- f: A function that takes the current optional timestamp and returns an optional new optional timestamp
Returns:
- The new optional timestamp if the update was successful, otherwise the current optional timestamp
Sourcepub fn expiration_state(
&self,
cur_ts: Timestamp,
expiration: TimestampDuration,
) -> Option<ExpirationState>
pub fn expiration_state( &self, cur_ts: Timestamp, expiration: TimestampDuration, ) -> Option<ExpirationState>
Check if a timestamp has expired atomically
Parameters:
- cur_ts: The current timestamp
- expiration: The expiration duration
Returns:
- true if the timestamp has expired, false if it has not
Sourcepub fn update_if_not_expired(
&self,
cur_ts: Timestamp,
expiration: TimestampDuration,
) -> ExpirationState
pub fn update_if_not_expired( &self, cur_ts: Timestamp, expiration: TimestampDuration, ) -> ExpirationState
Check if a timestamp is expired and update it to the current time if it is not, atomically. Useful for LRU caching.
Parameters:
- cur_ts: The current timestamp
- expiration: The expiration duration
Returns:
- true if the timestamp was updated, false if it was expired