pub struct AtomicTimestamp(/* private fields */);Expand description
Atomic wrapper for timestamps used in structs so we can avoid locks for LRU and similar operations
Implementations
Sourceimpl AtomicTimestamp
impl AtomicTimestamp
pub fn now() -> Self
pub fn now_non_decreasing() -> Self
pub fn now_increasing() -> Self
pub fn new(t: Timestamp) -> Self
pub fn get(&self) -> Timestamp
pub fn set(&self, t: Timestamp)
Sourcepub fn fetch_update(
&self,
f: impl FnMut(Timestamp) -> Option<Timestamp>,
) -> Result<Timestamp, Timestamp>
pub fn fetch_update( &self, f: impl FnMut(Timestamp) -> Option<Timestamp>, ) -> Result<Timestamp, Timestamp>
Fetch and update the timestamp atomically
Parameters:
- f: A function that takes the current timestamp and returns an optional new timestamp
Returns:
- The new timestamp if the update was successful, otherwise the current timestamp
Sourcepub fn expiration_state(
&self,
cur_ts: Timestamp,
expiration: TimestampDuration,
) -> ExpirationState
pub fn expiration_state( &self, cur_ts: Timestamp, expiration: TimestampDuration, ) -> ExpirationState
Check if a timestamp has expired atomically
Parameters:
- cur_ts: The current timestamp
- expiration: The expiration duration
Returns:
- true if the timestamp has expired, false if it has not
Sourcepub fn update_if_not_expired(
&self,
cur_ts: Timestamp,
expiration: TimestampDuration,
) -> ExpirationState
pub fn update_if_not_expired( &self, cur_ts: Timestamp, expiration: TimestampDuration, ) -> ExpirationState
Check if a timestamp is expired and update it to the current time if it is not, atomically. Useful for LRU caching.
Parameters:
- cur_ts: The current timestamp
- expiration: The expiration duration
Returns:
- true if the timestamp was updated, false if it was expired