pub struct BareKeyPair { /* private fields */ }Expand description
Untyped public/secret key pair, carrying no cryptosystem kind.
Implementations
Sourceimpl BareKeyPair
impl BareKeyPair
Sourcepub fn new(key: BarePublicKey, secret: BareSecretKey) -> Self
pub fn new(key: BarePublicKey, secret: BareSecretKey) -> Self
Builds a key pair from a public key and its secret key.
Sourcepub fn ref_key(&self) -> &BarePublicKey
pub fn ref_key(&self) -> &BarePublicKey
Returns a reference to the public key.
Sourcepub fn ref_secret(&self) -> &BareSecretKey
pub fn ref_secret(&self) -> &BareSecretKey
Returns a reference to the secret key.
Sourcepub fn ref_split(&self) -> (&BarePublicKey, &BareSecretKey)
pub fn ref_split(&self) -> (&BarePublicKey, &BareSecretKey)
Returns references to the public and secret keys.
Sourcepub fn split(&self) -> (BarePublicKey, BareSecretKey)
pub fn split(&self) -> (BarePublicKey, BareSecretKey)
Clones out the public and secret keys.
Sourcepub fn into_split(self) -> (BarePublicKey, BareSecretKey)
pub fn into_split(self) -> (BarePublicKey, BareSecretKey)
Consumes the pair, returning the public and secret keys.
Sourceimpl BareKeyPair
impl BareKeyPair
Sourcepub fn key(&self) -> BarePublicKey
pub fn key(&self) -> BarePublicKey
Returns a clone of the public key.
Sourcepub fn secret(&self) -> BareSecretKey
pub fn secret(&self) -> BareSecretKey
Returns a clone of the secret key.
Sourcepub fn encode(&self) -> String
pub fn encode(&self) -> String
Encodes the pair as <public>:<secret>, each part base64url-nopad.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the length of the encode string.
Sourcepub fn try_decode(input: &str) -> VeilidAPIResult<Self>
pub fn try_decode(input: &str) -> VeilidAPIResult<Self>
Decodes a pair from a <public>:<secret> string.
Errors with VeilidAPIError::ParseError if input is not exactly two colon-separated parts,
or VeilidAPIError::Generic if either part is not valid base64url-nopad.
Sourcepub fn try_decode_bytes(b: &[u8]) -> VeilidAPIResult<Self>
pub fn try_decode_bytes(b: &[u8]) -> VeilidAPIResult<Self>
Decodes a pair from <public>:<secret> bytes, requiring exactly two colon-separated parts.
Errors with VeilidAPIError::ParseError if b is not exactly two colon-separated parts,
or VeilidAPIError::Generic if either part is not valid base64url-nopad.