pub struct BareRecordKey { /* private fields */ }Expand description
Untyped DHT record key: an opaque record key with an optional record encryption secret.
Implementations
Sourceimpl BareRecordKey
impl BareRecordKey
Sourcepub fn new(
key: BareOpaqueRecordKey,
encryption_key: Option<BareSharedSecret>,
) -> Self
pub fn new( key: BareOpaqueRecordKey, encryption_key: Option<BareSharedSecret>, ) -> Self
Builds a record key from an opaque record key and an optional encryption secret.
Sourcepub fn ref_key(&self) -> &BareOpaqueRecordKey
pub fn ref_key(&self) -> &BareOpaqueRecordKey
Returns a reference to the opaque record key.
Sourcepub fn ref_encryption_key(&self) -> Option<&BareSharedSecret>
pub fn ref_encryption_key(&self) -> Option<&BareSharedSecret>
Returns a reference to the encryption secret, if present.
Sourcepub fn split(&self) -> (BareOpaqueRecordKey, Option<BareSharedSecret>)
pub fn split(&self) -> (BareOpaqueRecordKey, Option<BareSharedSecret>)
Clones out the opaque record key and optional encryption secret.
Sourcepub fn into_split(self) -> (BareOpaqueRecordKey, Option<BareSharedSecret>)
pub fn into_split(self) -> (BareOpaqueRecordKey, Option<BareSharedSecret>)
Consumes the key, returning the opaque record key and optional encryption secret.
Sourceimpl BareRecordKey
impl BareRecordKey
Sourcepub fn key(&self) -> BareOpaqueRecordKey
pub fn key(&self) -> BareOpaqueRecordKey
Returns a clone of the opaque record key.
Sourcepub fn encryption_key(&self) -> Option<BareSharedSecret>
pub fn encryption_key(&self) -> Option<BareSharedSecret>
Returns a clone of the encryption secret, if present.
Sourcepub fn encode(&self) -> String
pub fn encode(&self) -> String
Encodes as <key> or <key>:<encryption_key>, each part base64url-nopad.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the length of the encode string.
Sourcepub fn try_decode(input: &str) -> VeilidAPIResult<Self>
pub fn try_decode(input: &str) -> VeilidAPIResult<Self>
Decodes from a <key> or <key>:<encryption_key> string.
Errors with VeilidAPIError::ParseError if input has more than two colon-separated parts,
or VeilidAPIError::Generic if any part is not valid base64url-nopad.
Sourcepub fn try_decode_bytes(b: &[u8]) -> VeilidAPIResult<Self>
pub fn try_decode_bytes(b: &[u8]) -> VeilidAPIResult<Self>
Decodes from <key> or <key>:<encryption_key> bytes.
Errors with VeilidAPIError::ParseError if b has more than two colon-separated parts,
or VeilidAPIError::Generic if any part is not valid base64url-nopad.