pub struct PrivateSpec {
pub crypto_kinds: Vec<CryptoKind>,
pub hop_count: usize,
pub stability: Stability,
pub sequencing: Sequencing,
}Expand description
Options for private routes (receiver privacy).
Fields
crypto_kinds: Vec<CryptoKind>Empty value here will use all the available crypto kinds
hop_count: usizeIf zero this will be set to to the default route hop count
stability: StabilityPrefer reliability over speed.
sequencing: SequencingPrefer connection-oriented sequenced protocols.