pub struct SafetySpec {
pub preferred_route: Option<RouteId>,
pub hop_count: usize,
pub stability: Stability,
pub sequencing: Sequencing,
}Expand description
Options for safety routes (sender privacy).
Fields
preferred_route: Option<RouteId>Preferred safety route set id if it still exists.
hop_count: usizeIf zero this will be set to to the default route hop count
stability: StabilityPrefer reliability over speed.
sequencing: SequencingPrefer connection-oriented sequenced protocols.