pub struct Timestamp(/* private fields */);Expand description
8-byte-aligned u64 newtype that serializes as a string for JSON safety.
Implementations
Sourceimpl Timestamp
impl Timestamp
Sourcepub fn now() -> Self
pub fn now() -> Self
Current wall-clock time. May move backward if the system clock is adjusted.
Sourcepub fn now_non_decreasing() -> Self
pub fn now_non_decreasing() -> Self
Current time, clamped to never read earlier than a previous call. Repeated values are allowed.
Sourcepub fn now_increasing() -> Self
pub fn now_increasing() -> Self
Current time, clamped to always read at least 1us later than a previous call. Never repeats a value.
Sourcepub fn later(self, rhs: TimestampDuration) -> Self
pub fn later(self, rhs: TimestampDuration) -> Self
Timestamp shifted later by a duration, saturating at the maximum value.
Sourcepub fn earlier(self, rhs: TimestampDuration) -> Self
pub fn earlier(self, rhs: TimestampDuration) -> Self
Timestamp shifted earlier by a duration, saturating at zero.
Sourcepub fn duration_since(self, older: Self) -> TimestampDuration
pub fn duration_since(self, older: Self) -> TimestampDuration
Duration from older to this timestamp, saturating to zero if older is later.