pub struct TimestampDuration(/* private fields */);Expand description
8-byte-aligned u64 newtype that serializes as a string for JSON safety.
Implementations
Sourceimpl TimestampDuration
impl TimestampDuration
Sourcepub fn since(older: Timestamp) -> Self
pub fn since(older: Timestamp) -> Self
Elapsed time from older to now, saturating to zero if older is in the future.
Sourcepub fn since_non_decreasing(older: Timestamp) -> Self
pub fn since_non_decreasing(older: Timestamp) -> Self
Elapsed time from older to a non-decreasing now, saturating to zero if older is in the future.
Sourcepub fn seconds_u32(&self) -> Result<u32, String>
pub fn seconds_u32(&self) -> Result<u32, String>
Whole seconds as a u32, erroring if the value overflows.
Sourcepub fn millis_u32(&self) -> Result<u32, String>
pub fn millis_u32(&self) -> Result<u32, String>
Whole milliseconds as a u32, erroring if the value overflows.
Sourcepub fn seconds_f64(&self) -> f64
pub fn seconds_f64(&self) -> f64
Seconds as an f64, trading off least significant bits for range.
Sourcepub const fn saturating_add(self, rhs: Self) -> Self
pub const fn saturating_add(self, rhs: Self) -> Self
Add two durations, saturating at the maximum value.
Sourcepub const fn saturating_sub(self, rhs: Self) -> Self
pub const fn saturating_sub(self, rhs: Self) -> Self
Subtract a duration, saturating at zero.
Sourcepub const fn saturating_mul(self, rhs: u64) -> Self
pub const fn saturating_mul(self, rhs: u64) -> Self
Multiply by a scalar, saturating at the maximum value.
Sourcepub fn f64_mul(self, rhs: f64) -> Self
pub fn f64_mul(self, rhs: f64) -> Self
Multiply by an f64 scaling factor (not const due to float arithmetic)
Sourcepub const fn div_assign(&mut self, rhs: u64)
pub const fn div_assign(&mut self, rhs: u64)
Divide by a scalar in place.
Sourcepub fn checked_div<T: Into<u64>>(self, rhs: T) -> Option<Self>
pub fn checked_div<T: Into<u64>>(self, rhs: T) -> Option<Self>
Divide by a scalar, returning None on divide by zero.
Sourcepub fn checked_mul<T: Into<u64>>(self, rhs: T) -> Option<Self>
pub fn checked_mul<T: Into<u64>>(self, rhs: T) -> Option<Self>
Multiply by a scalar, returning None on overflow.
Sourcepub const fn saturating_add_assign(&mut self, rhs: Self)
pub const fn saturating_add_assign(&mut self, rhs: Self)
Add a duration in place, saturating at the maximum value.
Sourcepub const fn saturating_sub_assign(&mut self, rhs: Self)
pub const fn saturating_sub_assign(&mut self, rhs: Self)
Subtract a duration in place, saturating at zero.
Sourcepub const fn saturating_mul_assign(&mut self, rhs: u64)
pub const fn saturating_mul_assign(&mut self, rhs: u64)
Multiply by a scalar in place, saturating at the maximum value.