pub struct ValueData { /* private fields */ }Expand description
A DHT value and its metadata
Implementations
Sourceimpl ValueData
impl ValueData
Sourcepub fn new<B: Into<Bytes>>(data: B, writer: PublicKey) -> VeilidAPIResult<Self>
pub fn new<B: Into<Bytes>>(data: B, writer: PublicKey) -> VeilidAPIResult<Self>
Make a new value with sequence number ValueSeqNum::ZERO. Fails if data exceeds ValueData::MAX_LEN.
Errors with VeilidAPIError::Generic if data exceeds ValueData::MAX_LEN.
Sourcepub fn new_with_seq<B: Into<Bytes>>(
seq: ValueSeqNum,
data: B,
writer: PublicKey,
) -> VeilidAPIResult<Self>
pub fn new_with_seq<B: Into<Bytes>>( seq: ValueSeqNum, data: B, writer: PublicKey, ) -> VeilidAPIResult<Self>
Make a new value with an explicit sequence number. Fails if seq is ValueSeqNum::NONE or data exceeds ValueData::MAX_LEN.
Errors with VeilidAPIError::Generic if seq is ValueSeqNum::NONE or data exceeds ValueData::MAX_LEN.
Sourcepub fn ref_writer(&self) -> &PublicKey
pub fn ref_writer(&self) -> &PublicKey
The public identity key of the writer of the data, by reference
Sourcepub fn data_bytes(&self) -> Bytes
pub fn data_bytes(&self) -> Bytes
The stored bytes as an owned Bytes
Sourcepub fn seq(&self) -> ValueSeqNum
pub fn seq(&self) -> ValueSeqNum
The sequence number ordering this value among changes to the same subkey
Sourcepub fn total_size(&self) -> usize
pub fn total_size(&self) -> usize
The in-memory footprint of this value, including the struct itself and its data