pub struct VeilidAppMessage { /* private fields */ }Expand description
Direct statement blob passed to hosting application for processing.
Implementations
Sourceimpl VeilidAppMessage
impl VeilidAppMessage
Sourcepub fn new(
sender: Option<NodeId>,
route_id: Option<RouteId>,
message: Vec<u8>,
) -> Self
pub fn new( sender: Option<NodeId>, route_id: Option<RouteId>, message: Vec<u8>, ) -> Self
Construct an app message from its sender, optional route id, and payload.
Sourcepub fn sender(&self) -> Option<&NodeId>
pub fn sender(&self) -> Option<&NodeId>
Some(sender) if the message was sent directly, None if received via a private/safety route.