pub struct VeilidConfigInternalRPC {
pub concurrency: u32,
pub queue_size: u32,
pub max_timestamp_behind_ms: Option<u32>,
pub max_timestamp_ahead_ms: Option<u32>,
pub timeout_ms: u32,
pub max_route_hop_count: u8,
}Expand description
Internal “footgun” RPC configuration. See VeilidConfigInternal.
Fields
concurrency: u32Number of concurrent RPC worker tasks (0 = automatic).
queue_size: u32Maximum number of queued RPC operations.
max_timestamp_behind_ms: Option<u32>Reject messages timestamped more than this many ms in the past (None = no limit).
max_timestamp_ahead_ms: Option<u32>Reject messages timestamped more than this many ms in the future (None = no limit).
timeout_ms: u32Timeout for an RPC round-trip, in milliseconds.
max_route_hop_count: u8Maximum number of hops allowed in a route.