pub struct VeilidStateNetwork {
pub started: bool,
pub bps_down: ByteCount,
pub bps_up: ByteCount,
pub peers: Vec<PeerTableData>,
pub node_ids: Vec<NodeId>,
}Expand description
Describe the current network state of the Veilid node
Fields
started: boolIf the network has been started or not.
bps_down: ByteCountThe total number of bytes per second used by Veilid currently in the download direction.
bps_up: ByteCountThe total number of bytes per second used by Veilid currently in the upload direction.
peers: Vec<PeerTableData>The list of most recently accessed peers. This is not an active connection table, nor is representative of the entire routing table.
node_ids: Vec<NodeId>The list of node ids for this node