pub trait ToVeilidAPIErrorArgument {
// Required method
fn to_veilid_api_error_argument(&self) -> String;
}Expand description
Trait for types that can be directly converted into parameters for VeilidAPIError
Required Methods
Sourcefn to_veilid_api_error_argument(&self) -> String
fn to_veilid_api_error_argument(&self) -> String
Render this value as a string for inclusion in a VeilidAPIError message field.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".